@@ -16,8 +16,8 @@
 import json
 import os
 
-from neutron.services.trunk import constants as t_const
 from neutron_lib import constants as n_const
+from neutron_lib.services.trunk import constants as t_const
 from oslo_log import log as logging
 
 from networking_arista.common import constants as a_const
@@ -100,9 +100,9 @@ class AristaResourcesBase(object):
         self.clear_neutron_data()
 
     def update_neutron_resource(self, id, action):
-        LOG.info("%(pid)s Requesting %(action)s %(class)s resource %(id)s",
-                 {'action': action, 'class': self.__class__.__name__, 'id': id,
-                  'pid': os.getpid()})
+        LOG.debug("%(pid)s Requesting %(action)s %(class)s resource %(id)s",
+                  {'action': action, 'class': self.__class__.__name__,
+                   'id': id, 'pid': os.getpid()})
         resource = self.get_db_resources(id)
         if action == a_const.FULL_SYNC:
             self.clear_neutron_data()
@@ -118,30 +118,30 @@ class AristaResourcesBase(object):
             # worker.  We force this by removing the resource to our 'view' of
             # cvx resources
             self.force_resource_update(id)
-            LOG.info("%(pid)s Resource %(class)s %(id)s found, creating",
-                     {'class': self.__class__.__name__, 'id': id,
-                      'pid': os.getpid()})
+            LOG.debug("%(pid)s Resource %(class)s %(id)s found, creating",
+                      {'class': self.__class__.__name__, 'id': id,
+                       'pid': os.getpid()})
             self._add_neutron_resource(resource[0])
         else:
-            LOG.info("%(pid)s Resource %(class)s %(id)s not found, deleting",
-                     {'class': self.__class__.__name__, 'id': id,
-                      'pid': os.getpid()})
+            LOG.debug("%(pid)s Resource %(class)s %(id)s not found, deleting",
+                      {'class': self.__class__.__name__, 'id': id,
+                       'pid': os.getpid()})
             self._delete_neutron_resource(id)
 
     def _add_neutron_resource(self, resource):
         formatted_resource = self.format_for_create(resource)
         resource_id = list(formatted_resource.keys())[0]
-        LOG.info("%(pid)s %(class)s resource %(id)s added locally",
-                 {'class': self.__class__.__name__,
-                  'id': resource_id,
-                  'pid': os.getpid()})
+        LOG.debug("%(pid)s %(class)s resource %(id)s added locally",
+                  {'class': self.__class__.__name__,
+                   'id': resource_id,
+                   'pid': os.getpid()})
         # If the resource has changed, force a POST to CVX
         old_resource = self.neutron_resources.get(resource_id)
-        if old_resource and old_resource != formatted_resource:
-            LOG.info("%(pid)s %(class)s resource %(id)s requires update",
-                     {'class': self.__class__.__name__,
-                      'id': resource_id,
-                      'pid': os.getpid()})
+        if old_resource and old_resource != formatted_resource[resource_id]:
+            LOG.debug("%(pid)s %(class)s resource %(id)s requires update",
+                      {'class': self.__class__.__name__,
+                       'id': resource_id,
+                       'pid': os.getpid()})
             self.force_resource_update(resource_id)
         self.neutron_resources.update(formatted_resource)
 
@@ -155,9 +155,9 @@ class AristaResourcesBase(object):
         self.cvx_ids.add(id)
         try:
             del self.neutron_resources[id]
-            LOG.info("%(pid)s %(class)s resource %(id)s removed locally",
-                     {'class': self.__class__.__name__, 'id': id,
-                      'pid': os.getpid()})
+            LOG.debug("%(pid)s %(class)s resource %(id)s removed locally",
+                      {'class': self.__class__.__name__, 'id': id,
+                       'pid': os.getpid()})
         except KeyError:
             LOG.debug("Resource ID %(id)s already deleted locally", {'id': id})
 
@@ -169,10 +169,10 @@ class AristaResourcesBase(object):
         return set([resource[cls.id_key]])
 
     def get_cvx_ids(self):
-        LOG.info("%(pid)s Getting %(class)s from CVX",
-                 {'class': self.__class__.__name__,
-                  'pid': os.getpid()})
         if self.cvx_data_stale:
+            LOG.info("%(pid)s Getting %(class)s from CVX",
+                     {'class': self.__class__.__name__,
+                      'pid': os.getpid()})
             cvx_data = self.rpc.send_api_request(self.get_endpoint(), 'GET')
             for resource in cvx_data:
                 self.cvx_ids |= self.get_resource_ids(resource)
@@ -189,10 +189,10 @@ class AristaResourcesBase(object):
         return set(self.neutron_resources.keys())
 
     def get_neutron_resources(self):
-        LOG.info("%(pid)s Getting %(class)s from neutron",
-                 {'class': self.__class__.__name__,
-                  'pid': os.getpid()})
         if self.neutron_data_stale:
+            LOG.info("%(pid)s Getting %(class)s from neutron",
+                     {'class': self.__class__.__name__,
+                      'pid': os.getpid()})
             for resource in self.get_db_resources():
                 self._add_neutron_resource(resource)
             self.neutron_data_stale = False
@@ -239,9 +239,9 @@ class AristaResourcesBase(object):
                       'ids': ', '.join(str(r) for r in resource_ids_to_create),
                       'pid': os.getpid()})
         else:
-            LOG.info("%(pid)s No %(class)s resources to create",
-                     {'class': self.__class__.__name__,
-                      'pid': os.getpid()})
+            LOG.debug("%(pid)s No %(class)s resources to create",
+                      {'class': self.__class__.__name__,
+                       'pid': os.getpid()})
         return resources_to_create
 
     def delete_cvx_resources(self):
@@ -267,9 +267,9 @@ class AristaResourcesBase(object):
                       'ids': ', '.join(str(r) for r in resource_ids_to_delete),
                       'pid': os.getpid()})
         else:
-            LOG.info("%(pid)s No %(class)s resources to delete",
-                     {'class': self.__class__.__name__,
-                      'pid': os.getpid()})
+            LOG.debug("%(pid)s No %(class)s resources to delete",
+                      {'class': self.__class__.__name__,
+                       'pid': os.getpid()})
         return resources_to_delete
 
 
@@ -496,6 +496,21 @@ class PortBindings(AristaResourcesBase):
     endpoint = 'region/%(region)s/portbinding'
     get_db_resources = staticmethod(db_lib.get_port_bindings)
 
+    @staticmethod
+    def maybe_strip_fqdn(id):
+        port_id, binding = id
+        if type(binding) != tuple:
+            binding = utils.hostname(binding)
+        return (port_id, binding)
+
+    def force_resource_update(self, id):
+        id = self.maybe_strip_fqdn(id)
+        super(PortBindings, self).force_resource_update(id)
+
+    def _delete_neutron_resource(self, id):
+        id = self.maybe_strip_fqdn(id)
+        super(PortBindings, self)._delete_neutron_resource(id)
+
     @classmethod
     def get_resource_ids(cls, resource):
         resource_ids = set()
